@@ -1,7 +1,9 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ecos gmbh   www.ecos.de
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,14 +12,20 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: TimeHHMM.pm 410198 2006-05-30 06:49:55Z richter $
-#
 ###################################################################################
 
 
-package Embperl::Form::Validate::Time ;
+package Embperl::Form::Validate::TimeHHMM ;
 
 use base qw(Embperl::Form::Validate::Default);
+use utf8 ;
+
+my %errutf8 =
+    (
+	validate_time => 'Feld %0: "%1" ist kein gültiges Zeitformat. Geben Sie die Zeit in der Form hh:mm ein',
+    ) ;
+
+no utf8 ;
 
 my %error_messages = 
 (
@@ -26,10 +34,7 @@ my %error_messages =
 	validate_time => 'Feld %0: "%1" ist kein gltiges Zeitformat. Geben Sie die Zeit in der Form hh:mm ein',
     },
 
-    'de.utf-8' => 
-    {
-	validate_time => 'Feld %0: "%1" ist kein gültiges Zeitformat. Geben Sie die Zeit in der Form hh:mm ein',
-    },
+    'de.utf-8' => \%errutf8,
 
     en =>
     {
