@@ -1,7 +1,9 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2004 Gerald Richter / ecos gmbh   www.ecos.de
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,14 +12,20 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: Integer.pm,v 1.3 2004/01/23 06:50:57 richter Exp $
-#
 ###################################################################################
 
 
 package Embperl::Form::Validate::TimeValue ;
 
 use base qw(Embperl::Form::Validate::Integer);
+use utf8 ;
+
+my %errutf8 =
+    (
+	validate_time_long => 'Feld %0: "%1" ist kein gültiges Zeitformat. Geben Sie die Zeit in der Form hh:mm:ss ein',
+    ) ;
+
+no utf8 ;
 
 my %error_messages = 
 (
@@ -26,10 +34,7 @@ my %error_messages =
 	validate_timevalue => 'Feld %0: "%1" ist keine gltige Zeit. Geben Sie eine Zahl gefolgt von s, m, h, d oder w ein.',
     },
 
-    'de.utf-8' => 
-    {
-	validate_timevalue => 'Feld %0: "%1" ist keine gültige Zeit. Geben Sie eine Zahl gefolgt von s, m, h, d oder w ein.',
-    },
+    'de.utf-8' => \%errutf8,
 
     en =>
     {
