@@ -1,7 +1,9 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,8 +12,6 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: ASP.pm 294756 2005-08-07 00:03:03Z richter $
-#
 ###################################################################################
  
 package Embperl::Syntax::ASP ;
@@ -250,7 +250,7 @@ __END__
 
 =head1 NAME
 
-ASP syntax module for Embperl 
+Embperl::Syntax::ASP - ASP syntax module for Embperl 
 
 =head1 SYNOPSIS
 
@@ -291,7 +291,7 @@ the expression is inserted instead of the <%= %> block.
 
 =head1 Author
 
-Gerald Richter <richter@dev.ecos.de>
+Gerald Richter <richter at embperl dot org>
 
 =head1 See Also
 
