@@ -1,7 +1,9 @@
 
 ###################################################################################
 #
-#   Embperl - Copyright (c) 1997-2010 Gerald Richter / ECOS
+#   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -10,8 +12,6 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: Perl.pm 294756 2005-08-07 00:03:03Z richter $
-#
 ###################################################################################
  
 package Embperl::Syntax::Perl ;
@@ -72,7 +72,7 @@ __END__
 
 =head1 NAME
 
-Perl syntax module for Embperl 
+Embperl::Syntax::Perl - define Perl syntax for Embperl
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ without any markup.
 
 =head1 Author
 
-Gerald Richter <richter@dev.ecos.de>
+Gerald Richter <richter at embperl dot org>
 
 
 =cut
