@@ -6,20 +6,20 @@ sub new
     my ($self, $r) = @_ ;
 
     # The following two values must be changed to meet your local setup
-    # Additionaly DBI and DBIx::Recordset must be installed
+    # Additionally DBI and DBIx::Recordset must be installed
    
     $self -> {dbdsn}      = $^O eq 'MSWin32'?'dbi:ODBC:embperl':'dbi:mysql:embperl' ;
     $self -> {dbuser}     = 'www' ;
     $self -> {dbpassword} = undef ;
-    $self -> {adminemail} = 'richter@ecos.de';
-    $self -> {emailfrom}   = 'embperl@ecos.de';
+    $self -> {adminemail} = 'richter at embperl dot org';
+    $self -> {emailfrom}   = 'richter at embperl dot org';
 
-    # There is normaly no need to change anything below this line
+    # There is normally no need to change anything below this line
 
     $self -> {basepath}  = '/eg/web/' ;
     $self -> {baseuri}   = $ENV{EMBPERL_BASEURI} || '/eg/web/' ;
     $self -> {basedepth} = $ENV{EMBPERL_BASEDEPTH} || 2 ;
-    $self -> {imageuri}  = $ENV{EMBPERL_IMAGES} || '../images/' ;
+    $self -> {imageuri}  = $ENV{EMBPERL_IMAGES} || 'images/' ;
 
     $self -> {supported_languages} = ['en', 'de'] ;
     
@@ -28,21 +28,21 @@ sub new
     
     # check if Embperl 1.3 is installed
     if ($INC{'Apache2/RequestRec.pm'})
-	{
+        {
         my $lib_1_3 = dirname ($INC{'Apache2/RequestRec.pm'})  ;
         if (-e ($lib_1_3 . '/../HTML/Embperl.pod'))
             {
             $self -> {lib_1_3}     = dirname($lib_1_3) ;
             }
-	}
+        }
     elsif ($INC{'Apache.pm'})
-	{
+        {
         my $lib_1_3 = dirname ($INC{'Apache.pm'})  ;
         if (-e ($lib_1_3 . '/HTML/Embperl.pod'))
             {
             $self -> {lib_1_3}     = $lib_1_3 ;
             }
-	}
+        }
     $self -> {lib_1_3} ||= '' ;
 
     # check if DBIx::Recordset is installed
@@ -93,15 +93,15 @@ BEGIN
 
     @menu = (
         { menu => 'Home',                   uri => '',                          file => { en => 'eg/web/index.htm', de => 'eg/web/indexD.htm'} },
-        { menu => 'Features',               uri => 'pod/list/Features.htm',          file => { en => 'Features.pod',     de => 'FeaturesD.pod' }, sub =>
-            [
-            { menu => 'Features 1.3',               uri => 'Features13.htm',          path => { en => '%lib_1_3%/HTML/Embperl/Features.pod',     de => '%lib_1_3%/HTML/Embperl/FeaturesD.pod' } }
-            ]
+        { menu => 'Features',               uri => 'pod/list/Features.htm',          file => { en => 'Features.pod',     de => 'FeaturesD.pod' }, #sub =>
+        #     [
+        #     { menu => 'Features 1.3',               uri => 'Features13.htm',          path => { en => '%lib_1_3%/HTML/Embperl/Features.pod',     de => '%lib_1_3%/HTML/Embperl/FeaturesD.pod' } }
+        #     ]
         
          },
         { menu => 'Introduction',           uri => 'pod/intro/', sub =>
             [
-            { menu => 'Embperl',            uri => 'Intro.htm',                 file => 'Intro.pod', #file => { en => 'Intro.pod', 'de' => 'IntroD.pod'},
+            { menu => 'Embperl',            uri => 'Intro.htm',                 file => { en => 'Intro.pod', 'de' => 'IntroD.pod'},
                   desc => { en => 'Introduction of Embperl basic capablitities', 
                             de => 'Einfhrung in die grundlegenden Mglichkeiten von Embperl' }},
             { menu => 'Embperl::Object',    uri => 'IntroEmbperlObject.htm',    file => 'IntroEmbperlObject.pod',
@@ -120,13 +120,13 @@ BEGIN
                 { menu => 'README',            uri => 'README.txt',         file => { en => 'README', de => 'README'},
                   desc => { en => 'Short overview',
                             de => 'Kurzberblick' }},
-                { menu => 'README.v2',            uri => 'README.v2.txt',          file => { en => 'README.v2', de => 'README.v2'},
-                  desc => { en => 'Contains what\'s new in Embperl 2.0 and differences to Embperl 1.3',
-                            de => 'Enthlt die Neuigkeiten von Embperl 2.0 und die Unterschiede zu Embperl 1.3' }},
+                # { menu => 'README.v2',            uri => 'README.v2.txt',          file => { en => 'README.v2', de => 'README.v2'},
+                #   desc => { en => 'Contains what\'s new in Embperl 2.0 and differences to Embperl 1.3',
+                #             de => 'Enthlt die Neuigkeiten von Embperl 2.0 und die Unterschiede zu Embperl 1.3' }},
                 { menu => 'Configuration',           uri => 'Config.htm',               file => { en => 'Config.pod', de => 'Config.pod'},
                   desc => { en => 'Configuration and calling of Embperl', 
                             de => 'Konfiguration und Aufruf von Embperl' }},
-                { menu => 'Embperl',            uri => 'Embperl.htm',               file => 'Embperl.pod', #{ en => 'Embperl.pod', de => 'EmbperlD.pod'},
+                { menu => 'Embperl',            uri => 'Embperl.htm',               file => { en => 'Embperl.pod', de => 'EmbperlD.pod'},
                   desc => { en => 'Main Embperl documentation', de => 'Hauptdokumentation' }},
                 { menu => 'Embperl::Object',    uri => 'EmbperlObject.htm',         file => 'Embperl/Object.pm',
                   desc => { en => 'Documentation for creating object-oriented websites', 
@@ -170,34 +170,34 @@ BEGIN
                   desc => { en => 'Documentation on how to use Embperl for generating and sending mail', 
                             de => 'Dokumentation wie man Embperl benutzt um Mail zu erstellen und zu senden' }},
 #                { menu => 'Embperl::Util',    uri => 'EmbperlUtil.htm',         file => 'Embperl/Util.pm'},
-            { menu => '1.3.6 documentation',              uri => 'doc13.htm', 
-              desc => { en => 'Old documentation from Embperl 1.3.6', 
-                        de => 'Alte Dokumentation von Embperl 1.3.6' },
-              sub => ,
-                [
-                { menu => 'HTML::Embperl',         uri => 'HTML/Embperl.htm',               path => { en => '%lib_1_3%/HTML/Embperl.pod', de => '%lib_1_3%/HTML/EmbperlD.pod'},
-                  desc => { en => 'Main Embperl documentation: Configuration, Syntax, Usage etc.', 
-                            de => 'Hauptdokumentation: Konfiguration, Syntax, Benutzung, etc.' },
-                },
-                { menu => 'HTML::EmbperlObject',   uri => 'HTML/EmbperlObject.htm',         path => '%lib_1_3%/HTML/EmbperlObject.pm',
-                  desc => { en => 'Documentation for creating object-oriented websites', 
-                            de => 'Dokumentation zur Erstellung von Objekt-Orientierten Websites' }},
-                { menu => 'HTML::Embperl::Mail',   uri => 'HTML/Embperl/Mail.htm',          path => '%lib_1_3%/HTML/Embperl/Mail.pm' ,
-                  desc => { en => 'Documentation on how to use Embperl for generating and sending mail', 
-                            de => 'Dokumentation wie man Embperl benutzt um Mail zu erstellen und zu senden' }},
-                { menu => 'HTML::Embperl::Session',uri => 'HTML/Embperl/Session.htm',       path => '%lib_1_3%/HTML/Embperl/Session.pm' ,
-                  desc => { en => 'Documentation for Embperls session handling object', 
-                            de => 'Dokumentation ber Embperls Session Objekt' }},
-                { menu => 'Tips & Tricks',         uri => 'HTML/Embperl/TipsAndTricks.htm', path => '%lib_1_3%/HTML/Embperl/TipsAndTricks.pod' ,
-                  desc => { en => 'Tips & Tricks for Embperl 1.3.6', 
-                            de => 'Tips & Tricks fr Embperl 1.3.6' }},
+        #     { menu => '1.3.6 documentation',              uri => 'doc13.htm', 
+        #       desc => { en => 'Old documentation from Embperl 1.3.6', 
+        #                 de => 'Alte Dokumentation von Embperl 1.3.6' },
+        #       sub => ,
+        #         [
+        #         { menu => 'HTML::Embperl',         uri => 'HTML/Embperl.htm',               path => { en => '%lib_1_3%/HTML/Embperl.pod', de => '%lib_1_3%/HTML/EmbperlD.pod'},
+        #           desc => { en => 'Main Embperl documentation: Configuration, Syntax, Usage etc.', 
+        #                     de => 'Hauptdokumentation: Konfiguration, Syntax, Benutzung, etc.' },
+        #         },
+        #         { menu => 'HTML::EmbperlObject',   uri => 'HTML/EmbperlObject.htm',         path => '%lib_1_3%/HTML/EmbperlObject.pm',
+        #           desc => { en => 'Documentation for creating object-oriented websites', 
+        #                     de => 'Dokumentation zur Erstellung von Objekt-Orientierten Websites' }},
+        #         { menu => 'HTML::Embperl::Mail',   uri => 'HTML/Embperl/Mail.htm',          path => '%lib_1_3%/HTML/Embperl/Mail.pm' ,
+        #           desc => { en => 'Documentation on how to use Embperl for generating and sending mail', 
+        #                     de => 'Dokumentation wie man Embperl benutzt um Mail zu erstellen und zu senden' }},
+        #         { menu => 'HTML::Embperl::Session',uri => 'HTML/Embperl/Session.htm',       path => '%lib_1_3%/HTML/Embperl/Session.pm' ,
+        #           desc => { en => 'Documentation for Embperls session handling object', 
+        #                     de => 'Dokumentation ber Embperls Session Objekt' }},
+        #         { menu => 'Tips & Tricks',         uri => 'HTML/Embperl/TipsAndTricks.htm', path => '%lib_1_3%/HTML/Embperl/TipsAndTricks.pod' ,
+        #           desc => { en => 'Tips & Tricks for Embperl 1.3.6', 
+        #                     de => 'Tips & Tricks fr Embperl 1.3.6' }},
 
-                { menu => 'FAQ',                    uri => 'pod/Faq.htm',               path => '%lib_1_3%/HTML/Embperl/Faq.pod',
-                  desc => { en => 'FAQ for Embperl 1.3.6', 
-                            de => 'FAQ fr Embperl 1.3.6' }},
+        #         { menu => 'FAQ',                    uri => 'pod/Faq.htm',               path => '%lib_1_3%/HTML/Embperl/Faq.pod',
+        #           desc => { en => 'FAQ for Embperl 1.3.6', 
+        #                     de => 'FAQ fr Embperl 1.3.6' }},
 
-                ],
-            },
+        #         ],
+        #     },
             { menu => 'DBIx::Recordset',   uri => 'Recordset.htm',    path => '%lib_dbix%/DBIx/Recordset.pm',
                   desc => { en => 'Documentation of DBIx::Recordset', 
                             de => 'Dokumentation von DBIx::Recordset' }},
@@ -210,53 +210,54 @@ BEGIN
         
          },        #{ menu => 'FAQ',                    uri => 'pod/Faq.htm',               file => 'Faq.pod' },
         #{ menu => 'Examples',               uri => 'examples/' },
-        { menu => 'Download',                uri => 'pod/doc/Embperl.-page-19-.htm'},    #sect_44' },
-        { menu => 'Support',                uri => 'pod/doc/Embperl.-page-18-.htm', sub =>
-            [
-            { menu => 'Donate',                relurl => 'donate.htm',               file => { en => 'eg/web/donate.htm', de => 'eg/web/donateD.htm'} }
-            ]
+        #{ menu => 'Download',                uri => 'pod/doc/Embperl.-page-19-.htm'},    #sect_44' },
+        { menu => 'Support',                uri => 'pod/doc/Embperl.-page-17-.htm', 
+        # sub =>
+        #     [
+        #     { menu => 'Donate',                relurl => 'donate.htm',               file => { en => 'eg/web/donate.htm', de => 'eg/web/donateD.htm'} }
+        #     ]
         
-         },
+        },
         { menu => 'Changes',                 uri => 'pod/Changes.htm',           file => 'Changes.pod' },
         #{ menu => 'Sites using Embperl',    uri => 'pod/Sites.htm',             file => 'Sites.pod' },
-        { menu => 'Wiki',                uri => 'db/wiki/index.htm', file => '/eg/web/db/wiki.epl', same =>
-          [ 
-          { menu => 'Wiki',                uri => 'db/wiki/index.cgi', file => '/eg/web/db/wiki.epl' }, 
-          ] },
-        { menu => 'More infos',          uri => 'db/', sub => 
-            [
-            { menu => 'News',                    uri => 'news/news.htm',          file => 'eg/web/db/news/data.epd', fdat => { 'category_id' => 1 }, 
-                  desc => { en => 'Full list of all news.',
-                            de => 'Vollstndige Liste aller Neuigkeiten.' }},
-            { menu => 'Sites using Embperl',     uri => 'sites/sites.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 2 },
-                  desc => { en => 'Descriptions of Websites that use Embperl.',
-                            de => 'Beschreibung von Websites die Embperl einsetzen.' }},
-            { menu => 'Books',     uri => 'sites/books.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 3 },
-                  desc => { en => 'Books that contains informations about Embperl.',
-                            de => 'Bcher die Embperl behandeln.' }},
-            { menu => 'Articles',     uri => 'sites/articles.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 4 },
-                  desc => { en => 'Articles that covers Embperl.',
-                            de => 'Artikel die Embperl behandeln.' }},
-            { menu => 'Modules & Examples',     uri => 'sites/examples.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 6 },
-                  desc => { en => 'Modules and Examples with sourcecode for use/that uses Embperl.',
-                            de => 'Modules und Beispiele incl. Quelltext zur/unter Benutzung von Embperl.' }},
-            { menu => 'Editorsupport',     uri => 'sites/editors.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 5 },
-                  desc => { en => 'Syntaxhighligthing and other support for editors.',
-                            de => 'Syntaxhervorhebungen unter Untersttzung fr Editoren.' }},
-            { menu => 'Conferences',     uri => 'sites/conferences.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 7 },
-                  desc => { en => 'Talks about Embperl.',
-                            de => 'Vortrge ber Embperl.' }},
-            ],
-        },
-        { menu => 'Add info about Embperl',  uri => 'db/addsel.epl', same => 
-            [
-            { menu => 'Enter info to add about Embperl',    uri => 'db/add.epl' },
-            { menu => 'Show info added about Embperl',      uri => 'db/show.epl'},
-            { menu => 'Infos about Embperl',                uri => 'db/data.epd' },
-            { menu => 'Infos about Embperl',                uri => 'db/list.epl' },
-            ],
-        },
-        { menu => 'Login',                   uri => 'db/login.epl'},
+        # { menu => 'Wiki',                uri => 'db/wiki/index.htm', file => '/eg/web/db/wiki.epl', same =>
+        #   [ 
+        #   { menu => 'Wiki',                uri => 'db/wiki/index.cgi', file => '/eg/web/db/wiki.epl' }, 
+        #   ] },
+        # { menu => 'More infos',          uri => 'db/', sub => 
+        #     [
+        #     { menu => 'News',                    uri => 'news/news.htm',          file => 'eg/web/db/news/data.epd', fdat => { 'category_id' => 1 }, 
+        #           desc => { en => 'Full list of all news.',
+        #                     de => 'Vollstndige Liste aller Neuigkeiten.' }},
+        #     { menu => 'Sites using Embperl',     uri => 'sites/sites.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 2 },
+        #           desc => { en => 'Description of Websites that use Embperl.',
+        #                     de => 'Beschreibung von Websites die Embperl einsetzen.' }},
+        #     { menu => 'Books',     uri => 'sites/books.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 3 },
+        #           desc => { en => 'Books that contain information about Embperl.',
+        #                     de => 'Bcher die Embperl behandeln.' }},
+        #     { menu => 'Articles',     uri => 'sites/articles.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 4 },
+        #           desc => { en => 'Articles that cover Embperl.',
+        #                     de => 'Artikel die Embperl behandeln.' }},
+        #     { menu => 'Modules & Examples',     uri => 'sites/examples.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 6 },
+        #           desc => { en => 'Modules and Examples with source code for use/that uses Embperl.',
+        #                     de => 'Modules und Beispiele incl. Quelltext zur/unter Benutzung von Embperl.' }},
+        #     { menu => 'Editorsupport',     uri => 'sites/editors.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 5 },
+        #           desc => { en => 'Syntax highlighting and other support for editors.',
+        #                     de => 'Syntaxhervorhebungen unter Untersttzung fr Editoren.' }},
+        #     { menu => 'Conferences',     uri => 'sites/conferences.htm',        file => 'eg/web/db/data.epd', fdat => { 'category_id' => 7 },
+        #           desc => { en => 'Talks about Embperl.',
+        #                     de => 'Vortrge ber Embperl.' }},
+        #     ],
+        # },
+        # { menu => 'Add info about Embperl',  uri => 'db/addsel.epl', same => 
+        #     [
+        #     { menu => 'Enter info to add about Embperl',    uri => 'db/add.epl' },
+        #     { menu => 'Show info added about Embperl',      uri => 'db/show.epl'},
+        #     { menu => 'Infos about Embperl',                uri => 'db/data.epd' },
+        #     { menu => 'Infos about Embperl',                uri => 'db/list.epl' },
+        #     ],
+        # },
+        # { menu => 'Login',                   uri => 'db/login.epl'},
         ) ;
 
 
