@@ -1,7 +1,8 @@
 /*###################################################################################
 #
 #   Embperl - Copyright (c) 1997-2008 Gerald Richter / ecos gmbh  www.ecos.de
-#   Embperl - Copyright (c) 2008-2014 Gerald Richter
+#   Embperl - Copyright (c) 2008-2015 Gerald Richter
+#   Embperl - Copyright (c) 2015-2023 actevy.io
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -11,8 +12,6 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: eputil.c 1578075 2014-03-16 14:01:14Z richter $
-#
 ###################################################################################*/
 
 
@@ -1667,7 +1666,7 @@ void ChdirToSource (/*i/o*/ register req * r,
     
 /* ---------------------------------------------------------------------------- */
 /*                                                                              */
-/* Path serach                                                                  */
+/* Path search                                                                  */
 /*                                                                              */
 /* ---------------------------------------------------------------------------- */
 
